#
# spec file for package grandorgue
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define version_suffix 1

Name:           grandorgue
Version:        3.15.4
Release:        1.1
Summary:        Virtual Pipe Organ Software
License:        GPL-2.0-or-later
URL:            https://github.com/GrandOrgue/grandorgue
Source:         https://github.com/GrandOrgue/grandorgue/archive/%{version}-%{version_suffix}.tar.gz#/%{name}-%{version}-%{version_suffix}.tar.gz
BuildRequires:  ImageMagick
BuildRequires:  cmake
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  gcc-c++
BuildRequires:  gettext-tools
BuildRequires:  hicolor-icon-theme
BuildRequires:  libcurl-devel
BuildRequires:  libxslt-tools
BuildRequires:  po4a
BuildRequires:  update-desktop-files
BuildRequires:  wxGTK3-devel
BuildRequires:  zip
BuildRequires:  zita-convolver-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fftw3f)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(rtaudio)
BuildRequires:  pkgconfig(rtmidi)
BuildRequires:  pkgconfig(wavpack)
BuildRequires:  pkgconfig(yaml-cpp)
BuildRequires:  pkgconfig(zlib)
Recommends:     grandorgue-demo

%package demo
Summary:        GrandOrgue demo sampleset
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Midi
BuildArch:      noarch

%description
GrandOrgue is a virtual pipe organ sample player application supporting a HW1 compatible file format.

%description demo
This package contains the demo sampleset for GrandOrgue.

%prep
%setup -qn %{name}-%{version}-%{version_suffix}

%build
%cmake -DDOC_INSTALL_DIR=%{_docdir} \
       -DUSE_BUILD_SYSTEM_LIBDIR=ON \
       -DUSE_INTERNAL_RTAUDIO=OFF \
       -DUSE_INTERNAL_PORTAUDIO=OFF \
       -DUSE_INTERNAL_ZITACONVOLVER=OFF
%cmake_build

%install
%cmake_install
mkdir -p %{buildroot}%{_docdir}/%{name}
install -m 644 README* %{buildroot}%{_docdir}/%{name}
%find_lang GrandOrgue
%suse_update_desktop_file GrandOrgue

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files -f GrandOrgue.lang
%{_bindir}/*
%{_libdir}/libGrandOrgue*
%dir %{_datadir}/GrandOrgue/packages
%dir %{_datadir}/GrandOrgue
%doc %{_docdir}/%{name}
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/*
%{_datadir}/GrandOrgue/help
%{_datadir}/GrandOrgue/sounds
%{_datadir}/GrandOrgue/perftests
%{_datadir}/applications/*
%{_datadir}/mime/packages/*
%{_datadir}/icons/hicolor/*
%{_mandir}/man1/*

%files demo
%{_datadir}/GrandOrgue/packages/*.orgue

%changelog
* Thu Dec 26 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.15.4.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.15.4-1
  - Eliminated a MacOs debug alert when opening a settings dialog https://github.com/GrandOrgue/grandorgue/issues/2003
  - Fixed not releasing a pipe after fast switching between vave-based tremulant samples and regular pipe samples https://github.com/GrandOrgue/grandorgue/issues/2004
  - Removed support of MacOs 12
  - Fixed hang if there were lots of unused ODF entries https://github.com/GrandOrgue/grandorgue/issues/1918
* Tue Nov 26 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.15.3.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.15.3-1
  - Fixed crash of reference pipes with the "--justgui" option https://github.com/GrandOrgue/grandorgue/issues/2019
  - Fixed crash on attempt of loading an organ if it's files did not exist https://github.com/GrandOrgue/grandorgue/issues/1990
  - Fixed the sequencer "Save file" button not lightening after inserting or deleting a combination https://github.com/GrandOrgue/grandorgue/issues/2024
  - Fixed appearence, sizing and the scrollbar issues with the Stops window https://github.com/GrandOrgue/grandorgue/issues/1961
* Sat Oct 26 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.15.2.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.15.2-1
  - Fixed disengaging manually enabled stops when a crescendo was in the Override=Off mode https://github.com/GrandOrgue/grandorgue/issues/1935
  - Fixed non bringing a dialog windows on top when it had been already open https://github.com/GrandOrgue/grandorgue/issues/1961
  - Fixed combination button lighting when a crescendo was in the Override=Off mode https://github.com/GrandOrgue/grandorgue/issues/1935
* Fri Sep  6 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.15.1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.15.1-1
  - Fixed saving of Settings->Paths https://github.com/GrandOrgue/grandorgue/issues/1907
  - Fixed crash on releasing a key of any Binauralpipes organ https://github.com/GrandOrgue/grandorgue/issues/1986
  - Fixed absence of warnings of unused Pipe999ReleaseCrossfadeLength https://github.com/GrandOrgue/grandorgue/issues/1904
  - Fixed loading organ to not abort if reading InfoFilename failed and also fixed showing link in properties dialog if InfoFilename exists
* Thu Aug  8 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.15.0.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.15.0-1
  - Added capability of regex matching audio device names https://github.com/GrandOrgue/grandorgue/issues/1265
  - Added a checkbox-based Stops dialog (Audio/Midi -> Stops) https://github.com/GrandOrgue/grandorgue/issues/1816
  - Fixed not compatibilyty between polyphase interpolation and loseless compression https://github.com/GrandOrgue/grandorgue/issues/710
  - Fixed not sounding of pipe after an enclosure has closed to zero and then opened https://github.com/GrandOrgue/grandorgue/issues/1813
  - Added Midi listener for Panic button and Exit GO function. https://github.com/GrandOrgue/grandorgue/issues/1905
  - Added a tone balance (bass/treble harmonics balance) voicing option
* Mon Apr 29 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.14.2.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.14.2-1
  - Fixed divisional couplers with setter divisionals https://github.com/GrandOrgue/grandorgue/issues/1787
  - Fixed behavior of "Detect complex MIDI setup" with Note events in different cases https://github.com/GrandOrgue/grandorgue/issues/1762
  - Fixed the order of sending midi events from an On indicator. Now they are sent after sending all events from other controls https://github.com/GrandOrgue/grandorgue/issues/1762
* Wed Apr 17 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.14.1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.14.1-1
  - Fixed changing sound of a playing pipe without Pipe999IsTremulant when a wave tremulant state is changed https://github.com/GrandOrgue/grandorgue/issues/1855
  - Fixed crash on opening a very old config https://github.com/GrandOrgue/grandorgue/discussions/1869
  - Fixed ignoring initial midi setup when loading an organ with a preset without midi events configured https://github.com/GrandOrgue/grandorgue/issues/1785
  - Fixed saving Max release tail to the organ preset https://github.com/GrandOrgue/grandorgue/issues/1804
  - Fixed required package names in the BUILD.md file https://github.com/GrandOrgue/grandorgue/issues/1799
  - Added support of macOS on Apple silicon. GrandOrgue for macOS on Apple silicon requires macOS 14 or higher. GrandOrgue for macOS on Intel requires macOS 12.1 or higher. https://github.com/GrandOrgue/grandorgue/discussions/1153
  - Added ad-hoc code signing of GrandOrgue for macOS https://github.com/GrandOrgue/grandorgue/issues/1835
  - Fixed an error that occurred when trying to install the GrandOrgue RPM package https://github.com/GrandOrgue/grandorgue/issues/1859
* Fri Mar 29 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.14.0.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.14.0-1
  - Fixed crash on loading an organ without a pedal but wit a unison-off coupler https://github.com/GrandOrgue/grandorgue/issues/1846
  - Changed displaying of the right part of paths https://github.com/GrandOrgue/grandorgue/issues/1663
  - Added automatic update checking at startup (configurable) and the ability to check for updates from Help menu
  - Increased maximum value of allowed size to 32000 https://github.com/GrandOrgue/grandorgue/issues/1840
  - Added capability of specifying AmplitudeLevel, Gain, PitchTuning, PitchCorrection and TrackerDelay, Percussive, HasIndependentRelease at the WindchestGroup level of ODF
  - Added capability of specifying Percussive and HasIndependentRelease at the Organ level of ODF
  - Added capability of playing release of percussive pipes with Pipe999HasIndependentRelease=Y https://github.com/GrandOrgue/grandorgue/issues/1385
  - Fixed different encoding of combination .yaml files on Windows, Linux and MacOS https://github.com/GrandOrgue/grandorgue/issues/1818
  - Added support of "Couple Through" mode of Virtual Couplers https://github.com/GrandOrgue/grandorgue/issues/1657
  - Added capability of loading only GUI panels without audio samples by specifying the "-g" switch from the command line https://github.com/GrandOrgue/grandorgue/issues/1602
  - Removed support of MacOS 11 https://github.com/GrandOrgue/grandorgue/issues/1791
  - Fixed crash on loading an organ with a crescendo in Add mode https://github.com/GrandOrgue/grandorgue/issues/1772
  - Fixed crash with rtaudio/asio https://github.com/GrandOrgue/grandorgue/issues/1772
  - Added support of specifying different crossfade length for additional attack and release files https://github.com/GrandOrgue/grandorgue/issues/1760
  - Fixed wrong filename of the midi recorder file with Hungarian language settings https://github.com/GrandOrgue/grandorgue/issues/1644
  - Fixed unability to select the Hungarian language in the Organ Settings dialog
  - Eliminated resetting audio group with the Default button of Organ Settings dialog https://github.com/GrandOrgue/grandorgue/issues/731
* Mon Jan  8 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.13.3.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.13.3-1
  - Fixed not loading a pipe if some loop was not suitable for crossfade https://github.com/GrandOrgue/grandorgue/issues/1724
  - Fixed a wrong .wav filename in the log message window https://github.com/GrandOrgue/grandorgue/issues/1724
  - Increased the maximum number of Tremulants from 10 to 999
  - Fixed setting a reverb file name by default to the current directory https://github.com/GrandOrgue/grandorgue/issues/1741
  - Fixed crash on enabling convolution reverb https://github.com/GrandOrgue/grandorgue/issues/1741
  - Fixed hang on Panic button press on MacOs https://github.com/GrandOrgue/grandorgue/issues/1726
  - Fixed crash on switching divisionals when a bidirectional devisional coupler was engaged https://github.com/GrandOrgue/grandorgue/issues/1725
- Update to version 3.13.2.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.13.2-1
  - Fixed loading an organ when some configuration entry is out of range https://github.com/GrandOrgue/grandorgue/issues/1696
  - Fixed crash when trying to load a sample set with a truncated wave file https://github.com/GrandOrgue/grandorgue/discussions/370
  - Fixed crash on closing an organ https://github.com/GrandOrgue/grandorgue/issues/1678
* Sat Nov 18 2023 Dirk Müller <dmueller@suse.com>
- update to 3.13.1:
  * Fixed the maximal value of the "SYSEX Hauptwerk 32 Byte LCD"
    midi send events
  * Fixed discard in the Organ Settings dialog when multiple
    objects are selected
  * Moved all Organ Settings dialog buttons to the single button
    row
  * Decreased number of decimal digits in the Organ Settings
    dialog
  * Added a confirmation box when restoring Organ Settings to
    default
  * Replaced the Cancel and OK buttons in the Organ Settings
    dialog with the single Close button
  * Fixed change tracking and enableing/disabling the Discard and
    Apply buttons in the Organ Settings dialog
  * Renamed the Reset button to Discard in the Organ Settings
    dialog
  * Adopted the build instruction and the build scripts to new
    ubuntu versions
  * Improved concurrency handling
  * Added deregistering organs in the temporary directory that do
    not more exist
  * Fixed error messages after multiple runs of GrandOrgue ftom
    Appimage with a demo organ
  * Implemented option to send MIDI Note Off as 0x8X or 0x9X with
    velocity 0
  * Added capability of control buttons with Control Change MIDI
    events with different keys but same values using "Bx Ctrl
    Change Fixed On Value Toggle" and "Bx Ctrl Change Fixed Off
    Value Toggle"
  * Added saving dialog positions and sizes
  * Increased maximum value of Pipe999LoopCrossfadeLength and
    Pipe999ReleaseCrossfadeLength. Now they are 3000
  * Fixed saving manual switches as global in yaml
  * Fixed convolution enabling warrning in the Settings dialog
  * Fixed "Release Length is not valid" error when applying
    changes for several Organ Settings objects at once
  * Fixed saving all combinations as full
* Sun Jul 23 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.12.2.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.12.2-1
  - Fixed size of the Organ Settings Dialog https://github.com/GrandOrgue/grandorgue/issues/1415
  - Fixed an incorrect dialog window icon
  - Fixed absence of the Help button on the Organ Setting dialog https://github.com/GrandOrgue/grandorgue/issues/1416
  - Fixed displaying buttons if the manual is not visible https://github.com/GrandOrgue/grandorgue/issues/1566
  - Changed the default value of the CombinationsStoreNonDisplayedDrawstops ODF settings to false
  - Fixed capability of running on MacOs 11.3
  - Fixed "The device does not support requested channel count" error when using an USB audio card on MacOS https://github.com/GrandOrgue/grandorgue/issues/1550
* Tue Jun  6 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.12.1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.12.1-1
  - Fixed not storing switch state in combinations in organs with panels of the new style https://github.com/GrandOrgue/grandorgue/issues/1498
  - Fixed displaying light of various combination buttons https://github.com/GrandOrgue/grandorgue/issues/1536
  - Fixed saving empty and scoped combinations to yaml https://github.com/GrandOrgue/grandorgue/issues/1531
  - Fixed bug of GC not working on manual with only a single stop https://github.com/GrandOrgue/grandorgue/issues/1556
  - Fixed installation on linux with another yaml-cpp version than 6.2 https://github.com/GrandOrgue/grandorgue/issues/1548
* Fri May 26 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.12.0.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.12.0-1
  - Reverted back default display of GeneralPrev and GeneralNext https://github.com/GrandOrgue/grandorgue/issues/1538
  - Added new builtin bitmap set of manual keys and one new drawstop bitmap https://github.com/GrandOrgue/grandorgue/discussions/1490
  - Removed support of MacOs 10.15. Now MacOs 11 or above is required https://github.com/GrandOrgue/grandorgue/discussions/1149
  - Fixed warning "temperament would retune pipe by more than 600 cents" for retuned pipes https://github.com/GrandOrgue/ODFEdit/discussions/11#discussioncomment-5877020
  - Increased the maximum value of Enclosures from 50 to 999 https://github.com/GrandOrgue/grandorgue/issues/1484
* Tue May  9 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.11.2.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.11.2-1
  - Fixed crash on loading organ with general of divisional buttons https://github.com/GrandOrgue/grandorgue/issues/1512
* Thu May  4 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.11.1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.11.1-1
  - Fixed processing yaml combinations on organs with invisible couplers https://github.com/GrandOrgue/grandorgue/issues/1489
  - Fixed uncompatibility with recent linux distros. Use grandorgue-wx32 on new linux distros (where wxWidgets 3.0 is not available) https://github.com/GrandOrgue/grandorgue/issues/1480
  - Added support of negative y-axis adjustment of manual keys https://github.com/GrandOrgue/grandorgue/issues/1485
  - Fixed opening an organ with more than 50 windchest groups https://github.com/GrandOrgue/grandorgue/issues/1484
* Fri Apr 21 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.11.0.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.11.0-1
  - Added capability of navigating over, loading and saving the YAML combinations files on the Combination Setter panel https://github.com/GrandOrgue/grandorgue/issues/1196
  - Added capability of exporting and importing combinations in yaml format files https://github.com/GrandOrgue/grandorgue/issues/1195
  - Removed support of old linux distros (with libc6 versions before 2.31) https://github.com/GrandOrgue/grandorgue/discussions/1334
  - Fixed the translation of the desktop icon on Linux https://github.com/GrandOrgue/grandorgue/issues/1429
  - Added support of labels without a background image by specifying DispImageNum=0 https://github.com/GrandOrgue/grandorgue/issues/1386
  - Added capability of overriding wav MIDIPitchFraction with the Pipe999MIDIPitchFraction key https://github.com/GrandOrgue/grandorgue/issues/1378
- Remove gcc13_fix.patch since it is included in this version.
* Mon Mar 27 2023 Lukas Müller <expeehaa@outlook.com>
- Add gcc13_fix.patch from upstream to fix GCC13 build errors.
* Thu Mar  9 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.10.1-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.10.1-1
  - Fixed crash on loading an incorrect organ
- Changes from version 3.10.0-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.10.0-1
  - Added storing the GrandOrgueVersion key in the Organ Settings file https://github.com/GrandOrgue/grandorgue/issues/1375
  - Added capability of redefining ReleaseLength and IgnorePitch on each level of Organ Settings
  - Changed defaults for the General Setter elements to Piston https://github.com/GrandOrgue/grandorgue/issues/1360
  - Added new fields ManualTuning and AutoTuningCorrection of Organ Settings https://github.com/GrandOrgue/grandorgue/issues/1333
  - Fixed duplicating packaged organs in the organ list https://github.com/GrandOrgue/grandorgue/issues/1367
  - Fixed displaying a popup window when a cache had been created with another GO version https://github.com/GrandOrgue/grandorgue/issues/1363
  - Fixed not saving midi settings of divisional buttons https://github.com/GrandOrgue/grandorgue/issues/1350
  - Added PitchCorrection for organs and windchest. Pipe999PitchCorrection became additive to PitchCorrection of the rank, of the windchest and of the organ https://github.com/GrandOrgue/grandorgue/issues/1351
  - Added full support of '/' as the file sepearator in ODF unless 'Check ODF for HW1-compatibility' is set https://github.com/GrandOrgue/grandorgue/issues/827
  - Added support of ODF comments from ';' at any position to the end of line https://github.com/GrandOrgue/grandorgue/issues/828
* Tue Jan 24 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.9.5-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.9.5-1
  * Fixed saving position when some panel is outside the screen area #1271
  * Fixed playing release samples for very short notes #1222
  * Fixed help: the wrong panel positioning on wayland was documented #1271
  * Fixed typos and spelling errors in the Help
  * Fixed continuing loading an organ after an exception in one loading thread
  * Fixed size of text fields in the Organ Settings dialog on OsX #1315
  * Fixed missing the object filename in an error message if some exception occured when loading this object
* Tue Dec 13 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.9.4-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.9.4-1
  * Fixed starting 3.9.3 on Windows #1311
- Update to version 3.9.3-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.9.3-1
  * Fixed an old version number in the gnome application metadata #1304
  * Fixed switching off generals when using crescendo in not override mode #1299
  * Fixed error messages of GrandOrguePerf #1280
  * Fixed exit from GrandOrgue with an unhandled exception occurred on loading an organ
  * Fixed displaying output volume indicators on OSx #1255
  * Fixed sending midi-off events from generals and another pushbuttons #1291
  * Fixed crashing on exit in some cases
* Tue Nov 29 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.9.2-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.9.2-1
  * Fixed sending incorrect midi values from an enclosure #1267
  * Fixed not sending midi events from pushbuttons, including GC #1220
  * Fixed sending a midi event from an enclosure when it's value is not changed #1206
  * Fixed processing enclosures with high value is less than low value #1266
* Mon Nov 14 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.9.1-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.9.1-1
  * Fixed crash on loading an organ without a pedal #1249
  * Fixed SYSEX Hauptwerk max. length in MIDI event editor #1207
  * Fixed enclosure value calculation #1203
  * Fixed controlling stops with a touchscreen on Raspberry Pi #1208
* Thu Nov  3 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.9.0-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.9.0-1
  * Fixed playing multitrack midi files with changes of tempo https://github.com/GrandOrgue/grandorgue/discussions/1225
  * Fixed displaying audio ports on OSx #1216
  * Added divisional combination banks #708
  * Renamed audio ports: Pa to PortAudio and Rt to RtAudio #1216
  * Fixed size of the Organ Selection Dialog #1215
  * Fixed generals buttons behaviour with the crescendo in add mode #1209
  * Fixed an empty stop set to a general combination #1212
* Thu Sep 15 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.8.0-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.8.0-1
  * Fixed setting an empty stop set to a divisional combination #1068
  * Added capability of switching between the Override and the Add crescendo mode #1170
  * Fixed rebuilding the cache every time upon the appimage starts #1174
  * Fixed building appimage in an ubuntu container
* Tue Aug 16 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.7.0-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.7.0-1
  * Fixed packaging for OSx #1135
  * Deleting an organ in the Organ tab of the Settings dialog causes also deleting it's cache and all it's presets #1049
  * Reorganised the Organs tab of the Settings dialog #1119
  * Added capability of restoring organ settings values for all subobjects #1119
* Sun May 22 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.6.7-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.6.7-1
  * Added publishing debug symbols on windows builds #853
* Fri Apr 29 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.6.6-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.6.6-1
  * Fixed help issues #1066
  * Fixed saving organ settings on closing an organ or on finishing GrandOrgue #1069
  * Fixed setting up output midi events for all devices #1097
* Mon Apr 18 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.6.5-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.6.5-1
  * Fixed not saving the main window position and size in organ settings #1093
  * Fixed sound distortion while a reveberation is active #983
  * Fixed hang on reopening sound device (exit from settings, Panic) while a reveberation is active #983
  * Added support for building against system-wide ZitaConvolver library #1095
* Sun Mar 20 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.6.4-1.
  * Updated the copyright headers in the source code
  * Switched ZitaConvolver to an external source (github#983)
  * Added distribution of GrandOrguePerfTest in the GrandOrgue package (github#868)
  * Added the image file name to messages on loading this image (github#1063)
  * Fixed allowing to select disabled devices in the Midi Event Dialog (github#1044)
  * Fixed limits for PGM numbers of the Cx Program Change Range midi event (github#1058)
  * Clarified the guide how to obtain submodule sources manually in the BUILD.md (github#1062)
* Sat Mar  5 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.6.3-1.
* Sat Jan 29 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.6.1-1.
* Wed Jan 26 2022 Lukas Müller <expeehaa@outlook.com>
- Create package with version 3.6.1-0.
